==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_search.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_search.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("PAGE_NAME", "Search");

define("LAN_140", "Members");
define("LAN_180", "Search");
define("LAN_192", "All categories");
define("LAN_193", "Event Calendar");
define("LAN_194", "All Categories");
define("LAN_195", "Searching");
define("LAN_196", "matches");

define("LAN_197", "Downloads");
define("LAN_198", "No matches found");
define("LAN_199", "Search For:");

define("LAN_416", "You must be logged in to access this page");
define("LAN_417", "Search terms must be at least --CHARS-- characters.");

define("LAN_418", "Other Pages");

define("LAN_SEARCH_1", "Check All");
define("LAN_SEARCH_2", "Uncheck All");
define("LAN_SEARCH_3", "Posted on ");
define("LAN_SEARCH_4", "Match found in news title");
define("LAN_SEARCH_5", "Match found in news text");
define("LAN_SEARCH_6", "Match found in extended news text");
define("LAN_SEARCH_7", "Posted by ");
define("LAN_SEARCH_8", " on ");
define("LAN_SEARCH_9", "Untitled");
define("LAN_SEARCH_10", "Go to page:");
define("LAN_SEARCH_11", "Results");
define("LAN_SEARCH_12", " of ");
define("LAN_SEARCH_13", " in ");
define("LAN_SEARCH_14", "Category:");
define("LAN_SEARCH_15", "Author:");
define("LAN_SEARCH_17", "Sorry, search is restricted to one search every ");
define("LAN_SEARCH_18", " seconds.");
define("LAN_SEARCH_19", "Search In:");
define("LAN_SEARCH_20", "Authorisation Required");
define("LAN_SEARCH_21", "You are not authorised to view this page.");



define("LAN_SEARCH_22", "All Areas");
define("LAN_SEARCH_23", "Enhanced Query Form");
define("LAN_SEARCH_24", "Must contain word(s)");
define("LAN_SEARCH_25", "Must not contain word(s)");
define("LAN_SEARCH_26", "Exact Phrase");
define("LAN_SEARCH_27", "Word(s) beginning with");
define("LAN_SEARCH_28", "All Has No Advanced Search");
define("LAN_SEARCH_29", "Basic");
define("LAN_SEARCH_30", "Advanced");
define("LAN_SEARCH_31", "Has No Advanced Search");
define("LAN_SEARCH_32", "The following words were excluded from the search");
define("LAN_SEARCH_33", "The following word was excluded from the search");
define("LAN_SEARCH_34", "Newer than");
define("LAN_SEARCH_35", "Older than");
define("LAN_SEARCH_36", "Any time");
define("LAN_SEARCH_37", "One day");
define("LAN_SEARCH_38", "Two days");
define("LAN_SEARCH_39", "Three days");
define("LAN_SEARCH_40", "One week");
define("LAN_SEARCH_41", "Two weeks");
define("LAN_SEARCH_42", "Three weeks");
define("LAN_SEARCH_43", "One month");
define("LAN_SEARCH_44", "Two months");
define("LAN_SEARCH_45", "Three months");
define("LAN_SEARCH_46", "Half a year");
define("LAN_SEARCH_47", "One year");
define("LAN_SEARCH_48", "Two years");
define("LAN_SEARCH_49", "Three Years");

define("LAN_SEARCH_50", "Date posted");
define("LAN_SEARCH_51", "All categories");
define("LAN_SEARCH_52", "Match in");
define("LAN_SEARCH_53", "Whole item");
define("LAN_SEARCH_54", "Title only");
define("LAN_SEARCH_55", "Search in news category");
define("LAN_SEARCH_56", "All News Categories");
define("LAN_SEARCH_57", "Comments posted to");
define("LAN_SEARCH_58", "All Areas");
define("LAN_SEARCH_59", "All Comments");
define("LAN_SEARCH_60", "Comments posted to");
define("LAN_SEARCH_61", "By author");
define("LAN_SEARCH_62", "Date joined");
define("LAN_SEARCH_63", "Search in category");
define("LAN_SEARCH_64", "All Download Categories");
define("LAN_SEARCH_65", "Downloads");
define("LAN_SEARCH_66", "Date added");
define("LAN_SEARCH_67", "All downloads details");
define("LAN_SEARCH_68", "Date");
define("LAN_SEARCH_69", "Relevance");

define("LAN_SEARCH_70", "Posted to download item");
define("LAN_SEARCH_71", "Posted in reply to news item");
define("LAN_SEARCH_72", "Signature");
define("LAN_SEARCH_73", "No Signature.");
define("LAN_SEARCH_74", "Joined on");

define("LAN_SEARCH_75", "Search type");
define("LAN_SEARCH_76", "Posted on page");
define("LAN_SEARCH_77", "Posted on profile page of");

// Following formerly LAN_nnn - renamed to avoid clashes
define("LAN_SEARCH_98", "News");
define("LAN_SEARCH_99", "Comments");
//define("LAN_SEARCH_200", "Categories:");						// Redundant LAN?
define("LAN_SEARCH_201", "Please redefine your search query");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_search.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_search.php $
|     $Revision: 11678 $
|     $Id: lan_search.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("PAGE_NAME", "Search");

define("LAN_140", "Members");
define("LAN_180", "Search");
define("LAN_192", "All categories");
define("LAN_193", "Event Calendar");
define("LAN_194", "All Categories");
define("LAN_195", "Searching");
define("LAN_196", "matches");

define("LAN_197", "Downloads");
define("LAN_198", "No matches found");
define("LAN_199", "Search For:");

define("LAN_416", "You must be logged in to access this page");
define("LAN_417", "Search terms must be at least --CHARS-- characters.");

define("LAN_418", "Other Pages");

define("LAN_SEARCH_1", "Check All");
define("LAN_SEARCH_2", "Uncheck All");
define("LAN_SEARCH_3", "Posted on ");
define("LAN_SEARCH_4", "Match found in news title");
define("LAN_SEARCH_5", "Match found in news text");
define("LAN_SEARCH_6", "Match found in extended news text");
define("LAN_SEARCH_7", "Posted by ");
define("LAN_SEARCH_8", " on ");
define("LAN_SEARCH_9", "Untitled");
define("LAN_SEARCH_10", "Go to page:");
define("LAN_SEARCH_11", "Results");
define("LAN_SEARCH_12", " of ");
define("LAN_SEARCH_13", " in ");
define("LAN_SEARCH_14", "Category:");
define("LAN_SEARCH_15", "Author:");
define("LAN_SEARCH_17", "Sorry, search is restricted to one search every ");
define("LAN_SEARCH_18", " seconds.");
define("LAN_SEARCH_19", "Search In:");
define("LAN_SEARCH_20", "Authorisation Required");
define("LAN_SEARCH_21", "You are not authorised to view this page.");



define("LAN_SEARCH_22", "All Areas");
define("LAN_SEARCH_23", "Enhanced Query Form");
define("LAN_SEARCH_24", "Must contain word(s)");
define("LAN_SEARCH_25", "Must not contain word(s)");
define("LAN_SEARCH_26", "Exact Phrase");
define("LAN_SEARCH_27", "Word(s) beginning with");
define("LAN_SEARCH_28", "All Has No Advanced Search");
define("LAN_SEARCH_29", "Basic");
define("LAN_SEARCH_30", "Advanced");
define("LAN_SEARCH_31", "Has No Advanced Search");
define("LAN_SEARCH_32", "The following words were excluded from the search");
define("LAN_SEARCH_33", "The following word was excluded from the search");
define("LAN_SEARCH_34", "Newer than");
define("LAN_SEARCH_35", "Older than");
define("LAN_SEARCH_36", "Any time");
define("LAN_SEARCH_37", "One day");
define("LAN_SEARCH_38", "Two days");
define("LAN_SEARCH_39", "Three days");
define("LAN_SEARCH_40", "One week");
define("LAN_SEARCH_41", "Two weeks");
define("LAN_SEARCH_42", "Three weeks");
define("LAN_SEARCH_43", "One month");
define("LAN_SEARCH_44", "Two months");
define("LAN_SEARCH_45", "Three months");
define("LAN_SEARCH_46", "Half a year");
define("LAN_SEARCH_47", "One year");
define("LAN_SEARCH_48", "Two years");
define("LAN_SEARCH_49", "Three Years");

define("LAN_SEARCH_50", "Date posted");
define("LAN_SEARCH_51", "All categories");
define("LAN_SEARCH_52", "Match in");
define("LAN_SEARCH_53", "Whole item");
define("LAN_SEARCH_54", "Title only");
define("LAN_SEARCH_55", "Search in news category");
define("LAN_SEARCH_56", "All News Categories");
define("LAN_SEARCH_57", "Comments posted to");
define("LAN_SEARCH_58", "All Areas");
define("LAN_SEARCH_59", "All Comments");
define("LAN_SEARCH_60", "Comments posted to");
define("LAN_SEARCH_61", "By author");
define("LAN_SEARCH_62", "Date joined");
define("LAN_SEARCH_63", "Search in category");
define("LAN_SEARCH_64", "All Download Categories");
define("LAN_SEARCH_65", "Downloads");
define("LAN_SEARCH_66", "Date added");
define("LAN_SEARCH_67", "All downloads details");
define("LAN_SEARCH_68", "Date");
define("LAN_SEARCH_69", "Relevance");

define("LAN_SEARCH_70", "Posted to download item");
define("LAN_SEARCH_71", "Posted in reply to news item");
define("LAN_SEARCH_72", "Signature");
define("LAN_SEARCH_73", "No Signature.");
define("LAN_SEARCH_74", "Joined on");

define("LAN_SEARCH_75", "Search type");
define("LAN_SEARCH_76", "Posted on page");
define("LAN_SEARCH_77", "Posted on profile page of");

// Following formerly LAN_nnn - renamed to avoid clashes
define("LAN_SEARCH_98", "News");
define("LAN_SEARCH_99", "Comments");
//define("LAN_SEARCH_200", "Categories:");						// Redundant LAN?
define("LAN_SEARCH_201", "Please redefine your search query");

?>
